# cbmi_utils

Utility package for common features at CBMI. Further Information can be found in the [Wiki](https://git.tools.f4.htw-berlin.de/baumapa/cbmi_utils/-/wikis/home).

## Install
```
pip install cbmi-utils
```

## Usage
Example PyTorch Layer Import
```
from cbmi_utils.pytorch.layers import Reshape
```